@@ -5,7 +5,7 @@ describe 'documentation' do
   let(:define_msg) { 'defined type not documented' }
 
   describe 'undocumented class' do
-    let(:code) { "class test {}" }
+    let(:code) { 'class test {}' }
 
     it 'should only detect a single problem' do
       expect(problems).to have(1).problem
@@ -17,10 +17,12 @@ describe 'documentation' do
   end
 
   describe 'documented class' do
-    let(:code) { "
-      # foo
-      class test {}
-    "}
+    let(:code) do
+      <<-END
+        # foo
+        class test {}
+      END
+    end
 
     it 'should not detect any problems' do
       expect(problems).to have(0).problems
@@ -28,7 +30,7 @@ describe 'documentation' do
   end
 
   describe 'undocumented defined type' do
-    let(:code) { "define test {}" }
+    let(:code) { 'define test {}' }
 
     it 'should only detect a single problem' do
       expect(problems).to have(1).problem
@@ -40,10 +42,12 @@ describe 'documentation' do
   end
 
   describe 'documented defined type' do
-    let(:code) { "
-      # foo
-      define test {}
-    "}
+    let(:code) do
+      <<-END
+        # foo
+        define test {}
+      END
+    end
 
     it 'should not detect any problems' do
       expect(problems).to have(0).problems
