@@ -1,15 +1,22 @@
 # encoding: utf-8
+
 require 'spec_helper'
 
 describe '80chars' do
+  before do
+    PuppetLint.configuration.send('enable_80chars')
+  end
+
   let(:msg) { 'line has more than 80 characters' }
 
   context 'file resource with a source line > 80c' do
-    let(:code) { "
-      file {
-        source  => 'puppet:///modules/certificates/etc/ssl/private/wildcard.example.com.crt',
-      }"
-    }
+    let(:code) do
+      <<-END
+        file {
+          source  => 'puppet:///modules/certificates/etc/ssl/private/wildcard.example.com.crt',
+        }
+      END
+    end
 
     it 'should not detect any problems' do
       expect(problems).to have(0).problems
@@ -17,11 +24,13 @@ describe '80chars' do
   end
 
   context 'file resource with a template line > 80c' do
-    let(:code) { "
-      file {
-        content => template('mymodule/this/is/a/truely/absurdly/long/path/that/should/make/you/feel/bad'),
-      }"
-    }
+    let(:code) do
+      <<-END
+        file {
+          content => template('mymodule/this/is/a/truely/absurdly/long/path/that/should/make/you/feel/bad'),
+        }
+      END
+    end
 
     it 'should not detect any problems' do
       expect(problems).to have(0).problems
@@ -29,11 +38,13 @@ describe '80chars' do
   end
 
   context 'length of lines with UTF-8 characters' do
-    let(:code) { "
-      # ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
-      # ┃          Configuration           ┃
-      # ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛"
-    }
+    let(:code) do
+      <<-END
+        # ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
+        # ┃          Configuration           ┃
+        # ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛"
+      END
+    end
 
     it 'should not detect any problems' do
       expect(problems).to have(0).problems
